Third Party Notices
===================

The New Relic OpenCensus Exporter uses source code from third party libraries
which carry their own copyright notices and license terms. These notices are
provided below.

In the event that a required notice is missing or incorrect, please
notify us by e-mailing open-source@newrelic.com.

`opencensus <https://pypi.org/project/opencensus>`__
----------------------------------------------------

Copyright 2016-17, OpenCensus Authors

Copyright 2017, OpenCensus Authors

Copyright 2018, OpenCensus Authors

Copyright 2019, OpenCensus Authors

Distributed under the following license(s):

-  `Apache License, Version 2.0 <https://www.apache.org/licenses/LICENSE-2.0>`__
